@@ -76,7 +76,7 @@ class CarlaAboutW(QDialog):
         self.ui.l_about.setText(self.tr(""
                                      "<br>Version %s"
                                      "<br>Carla is a fully-featured audio plugin host%s.<br>"
-                                     "<br>Copyright (C) 2011-2018 falkTX<br>"
+                                     "<br>Copyright (C) 2011-2019 falkTX<br>"
                                      "" % (VERSION, extraInfo)))
 
         if self.ui.about.palette().color(QPalette.Background).blackF() < 0.5:
@@ -100,19 +100,19 @@ class CarlaAboutW(QDialog):
             self.ui.le_osc_url_udp.setText(self.tr("(Engine not running)"))
 
         self.ui.l_osc_cmds.setText("<table>"
-                                   "<tr><td>" "/set_active"                 "&nbsp;</td><td>&lt;" "i-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_drywet"                 "&nbsp;</td><td>&lt;" "f-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_volume"                 "&nbsp;</td><td>&lt;" "f-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_balance_left"           "&nbsp;</td><td>&lt;" "f-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_balance_right"          "&nbsp;</td><td>&lt;" "f-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_panning"                "&nbsp;</td><td>&lt;" "f-value" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_parameter_value"        "&nbsp;</td><td>&lt;" "i-index" "&gt;</td><td>&lt;" "f-value"   "&gt;</td></tr>"
-                                   "<tr><td>" "/set_parameter_midi_cc"      "&nbsp;</td><td>&lt;" "i-index" "&gt;</td><td>&lt;" "i-cc"      "&gt;</td></tr>"
-                                   "<tr><td>" "/set_parameter_midi_channel" "&nbsp;</td><td>&lt;" "i-index" "&gt;</td><td>&lt;" "i-channel" "&gt;</td></tr>"
-                                   "<tr><td>" "/set_program"                "&nbsp;</td><td>&lt;" "i-index" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/set_midi_program"           "&nbsp;</td><td>&lt;" "i-index" "&gt;</td><td>"                     "</td></tr>"
-                                   "<tr><td>" "/note_on"                    "&nbsp;</td><td>&lt;" "i-note"  "&gt;</td><td>&lt;" "i-velo"    "&gt;</td></tr>"
-                                   "<tr><td>" "/note_off"                   "&nbsp;</td><td>&lt;" "i-note"  "&gt;</td><td>"                     "</td></tr>"
+                                   "<tr><td>" "/set_active"                 "&nbsp;</td><td>&lt;i-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_drywet"                 "&nbsp;</td><td>&lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_volume"                 "&nbsp;</td><td>&lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_balance_left"           "&nbsp;</td><td>&lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_balance_right"          "&nbsp;</td><td>&lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_panning"                "&nbsp;</td><td>&lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_parameter_value"        "&nbsp;</td><td>&lt;i-index&gt; &lt;f-value&gt;</td></tr>"
+                                   "<tr><td>" "/set_parameter_midi_cc"      "&nbsp;</td><td>&lt;i-index&gt; &lt;i-cc&gt;</td></tr>"
+                                   "<tr><td>" "/set_parameter_midi_channel" "&nbsp;</td><td>&lt;i-index&gt; &lt;i-channel&gt;</td></tr>"
+                                   "<tr><td>" "/set_program"                "&nbsp;</td><td>&lt;i-index&gt;</td></tr>"
+                                   "<tr><td>" "/set_midi_program"           "&nbsp;</td><td>&lt;i-index&gt;</td></tr>"
+                                   "<tr><td>" "/note_on"                    "&nbsp;</td><td>&lt;i-channel&gt; &lt;i-note&gt; &lt;i-velo&gt;</td></tr>"
+                                   "<tr><td>" "/note_off"                   "&nbsp;</td><td>&lt;i-channel&gt; &lt;i-note</td></tr>"
                                    "</table>"
                                   )
 
